==> speech-analytic-testing_2.2.2_database.tar.gz: database/mssql/procedures/GetAllegroCampaignMembers.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetAllegroCampaignMembers]
(
	@IP				VARCHAR(50),
	@VCC			VARCHAR(50),
	@Campaigns		VARCHAR(MAX),
	@Type			BIT
)
AS
BEGIN
	-- ESTE SP RETORNA LA LISTA DE SUPERVISORES DE UN VCC DE TIPO ALLEGRO/OCC CON SUS WORKGROUPS DE AGENTES
	
	-- DECLARAMOS VARIABLES PARA ARMAR LA CONSULTA
	DECLARE @SQL VARCHAR(MAX) = NULL
	DECLARE @TABLE_MMPRODAT VARCHAR(100) = NULL

	-- EL TYPE 0 INDICA QUE LAS TABLAS SE ENCUENTRAN EN UN SERVIDOR EXTERNO
	IF @Type = 0
	BEGIN  
		SET @TABLE_MMPRODAT = '[' + @Ip + ']' + '.[MMProDat].[dbo].'
	END
	ELSE IF(@Type = 1) 
	BEGIN
		SET @TABLE_MMPRODAT = '[MMProDat].[dbo].'
	END
	
	-- ARMAMOS LA CONSULTA PRINCIPAL
	/*
	SET @SQL = '
		SELECT DISTINCT UC.[VCC]					''vcc'',
						UC.[CampaignId]				''campaign'',
						UC.[Id]						''userId''
			FROM ' + @TABLE_MMPRODAT + '[UserCampaign] UC (NOLOCK)
			WHERE UC.[VCC] = ''' + @VCC + ''' 
				AND UC.[CampaigniD] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
	*/

	SELECT DISTINCT UC.[VCC]									'vcc',
					UC.[CampaignId]								'campaignId',
					UC.[UserId]									'userId',
					IIF(SWG.[SupervisorId] IS NOT NULL, 1, 0)	'isSupervisor',
					IIF(A.[UserId] IS NOT NULL, 1, 0)			'isAgent',
					SWG.[WorkgroupId]							'supervisorWorkgroup',
					A.[WorkgroupId]								'agentWorkgroup'
		FROM [MMProDat].[dbo].[UserCampaign] UC (NOLOCK)
		LEFT JOIN [MMProDat].[dbo].[Agent] A (NOLOCK)
			ON A.[VCC] = UC.[VCC]
				AND A.[UserId] = UC.[UserId]
		LEFT JOIN [MMProDat].[dbo].[SupervisorWorkgroup] SWG (NOLOCK)
			ON SWG.[VCC] = UC.[VCC]
				AND SWG.[CampaignId] = UC.[CampaignId]
				AND SWG.[SupervisorId] = UC.[UserId]
 		WHERE UC.[VCC] = @VCC 
			AND UC.[CampaignId] IN (SELECT Value FROM [dbo].[split](@Campaigns,','))

	-- EJECUTAMOS LA CONSULTA
	EXEC(@SQL)
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/GetAllegroCampaignMembers.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetAllegroCampaignMembers]
(
	@IP				VARCHAR(50),
	@VCC			VARCHAR(50),
	@Campaigns		VARCHAR(MAX),
	@Type			BIT
)
AS
BEGIN
	-- ESTE SP RETORNA LA LISTA DE SUPERVISORES DE UN VCC DE TIPO ALLEGRO/OCC CON SUS WORKGROUPS DE AGENTES
	
	-- DECLARAMOS VARIABLES PARA ARMAR LA CONSULTA
	DECLARE @SQL VARCHAR(MAX) = NULL
	DECLARE @TABLE_MMPRODAT VARCHAR(100) = NULL

	-- EL TYPE 0 INDICA QUE LAS TABLAS SE ENCUENTRAN EN UN SERVIDOR EXTERNO
	IF @Type = 0
	BEGIN  
		SET @TABLE_MMPRODAT = '[' + @Ip + ']' + '.[MMProDat].[dbo].'
	END
	ELSE IF(@Type = 1) 
	BEGIN
		SET @TABLE_MMPRODAT = '[MMProDat].[dbo].'
	END
	
	-- ARMAMOS LA CONSULTA PRINCIPAL
	/*
	SET @SQL = '
		SELECT DISTINCT UC.[VCC]					''vcc'',
						UC.[CampaignId]				''campaign'',
						UC.[Id]						''userId''
			FROM ' + @TABLE_MMPRODAT + '[UserCampaign] UC (NOLOCK)
			WHERE UC.[VCC] = ''' + @VCC + ''' 
				AND UC.[CampaigniD] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
	*/

	SELECT DISTINCT UC.[VCC]									'vcc',
					UC.[CampaignId]								'campaignId',
					UC.[UserId]									'userId',
					IIF(
						(
							SWG.[SupervisorId] IS NOT NULL
							OR 
							U.[UserGroup] = 'supervisor'
						), 1, 0)	'isSupervisor',
					IIF(A.[UserId] IS NOT NULL, 1, 0)			'isAgent',
					SWG.[WorkgroupId]							'supervisorWorkgroup',
					A.[WorkgroupId]								'agentWorkgroup'
		FROM [MMProDat].[dbo].[UserCampaign] UC (NOLOCK)
		LEFT JOIN [MMProDat].[dbo].[Agent] A (NOLOCK)
			ON A.[VCC] = UC.[VCC]
				AND A.[UserId] = UC.[UserId]
		LEFT JOIN [MMProDat].[dbo].[SupervisorWorkgroup] SWG (NOLOCK)
			ON SWG.[VCC] = UC.[VCC]
				AND SWG.[CampaignId] = UC.[CampaignId]
				AND SWG.[SupervisorId] = UC.[UserId]
		LEFT JOIN [MMProDat].[dbo].[User] U (NOLOCK)
			ON U.[VCC] = UC.[VCC]
				AND U.[Id] = UC.[UserId]
 		WHERE UC.[VCC] = @VCC 
			AND UC.[CampaignId] IN (SELECT Value FROM [dbo].[split](@Campaigns,','))

	-- EJECUTAMOS LA CONSULTA
	EXEC(@SQL)
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
